Bibliography
============

.. [TSN] `Temporal Segment Networks: Towards Good Practices for Deep Action Recognition, Limin Wang, Yuanjun Xiong, Zhe Wang, Yu Qiao, Dahua Lin, Xiaoou Tang, Luc Van Gool <https://arxiv.org/abs/1608.00859>`_
